::: {#navbar .navbar .navbar-default .navbar-fixed-top role="navigation"}
::: {.container}
::: {.navbar-header}
[]{.icon-bar} []{.icon-bar} []{.icon-bar}

<div>

[![](../_static/img/RAIcon.png)](/runestone/default/user/login){.brand-logo}
[fopp](../index.html){#rs-book-toc-link .navbar-brand}

</div>
:::

::: {.navbar-collapse .collapse .navbar-ex1-collapse}
-   
-   []{#ad_warning}
-   []{#browsing_warning}
-   
-   [*[Search]{.visuallyhidden
    aria-label="Search"}*](#){.dropdown-toggle}
    -   [Table of Contents](../index.html)

    -   [Book Index](../genindex.html)

    -   

    -   ::: {.input-group}
        :::
-   
-   [*[User]{.visuallyhidden aria-label="User"}*](#){.dropdown-toggle}
    -   []{.loggedinuser}

    -   

    -   [Course Home](/ns/course/index)

    -   [Assignments](/assignment/student/chooseAssignment)

    -   [Practice](/runestone/assignments/practice)

    -   [[Peer Instruction
        (Instructor)](/runestone/peer/instructor.html)]{#inst_peer_link}

    -   [Peer Instruction (Student)](/runestone/peer/student.html)

    -   

    -   [Change Course](/runestone/default/courses)

    -   

    -   [[Instructor\'s
        Page](/runestone/admin/index)]{#ip_dropdown_link}

    -   [Progress Page](/runestone/dashboard/studentreport)

    -   

    -   [Edit Profile](/runestone/default/user/profile){#profilelink}

    -   [Change
        Password](/runestone/default/user/change_password){#passwordlink}

    -   [Register](/runestone/default/user/register){#registerlink}

    -   [Login](#)

    -   ::: {.slider .round}
        :::

        Dark Mode
-   
-   [[*[Scratch Activecode]{.visuallyhidden
    aria-label="Scratch Activecode"}*](javascript:runestoneComponents.popupScratchAC())]{#scratch_ac_link}
-   
-   [*[Help]{.visuallyhidden aria-label="Help"}*](#){.dropdown-toggle}
    -   [FAQ](http://runestoneinteractive.org/pages/faq.html)
    -   [Instructors Guide](https://guide.runestone.academy)
    -   
    -   [About Runestone](http://runestoneinteractive.org)
    -   [Report A
        Problem](/runestone/default/reportabug?course=fopp&page=week1a3)
-   

```{=html}
<!-- -->
```
-   
-   [This Chapter](../index.html){.dropdown-toggle}
    -   [5.1 Hello Little
        Turtles!](intro-HelloLittleTurtles.html){.reference .internal}
    -   [5.2 Our First Turtle
        Program](OurFirstTurtleProgram.html){.reference .internal}
    -   [5.3 Instances: A Herd of
        Turtles](InstancesAHerdofTurtles.html){.reference .internal}
    -   [5.4 Object Oriented Concepts](ObjectInstances.html){.reference
        .internal}
    -   [5.5 Repetition with a For
        Loop](RepetitionwithaForLoop.html){.reference .internal}
    -   [5.6 A Few More turtle Methods and
        Observations](AFewMoreturtleMethodsandObservations.html){.reference
        .internal}
    -   [5.7 Summary of Turtle
        Methods](SummaryOfTurtleMethods.html){.reference .internal}
    -   [5.8 👩‍💻 Incremental
        Programming](WPIncrementalProgramming.html){.reference
        .internal}
    -   [5.9 👩‍💻 Common turtle
        Errors](WPCommonTurtleErrors.html){.reference .internal}
    -   [5.10 Exercises](Exercises.html){.reference .internal}
    -   [5.11 Chapter Assessment - Turtle and Object
        Mechanics](week1a3.html){.reference .internal}
-   
-   
:::
:::
:::

::: {#continue-reading .container}
:::

::: {#main-content .container role="main"}
::: {#chapter-assessment-turtle-and-object-mechanics .section}
[5.11. ]{.section-number}Chapter Assessment - Turtle and Object Mechanics[¶](#chapter-assessment-turtle-and-object-mechanics "Permalink to this heading"){.headerlink}
======================================================================================================================================================================

**Check your understanding**

::: {.runestone}
-   [Tex.forward(20)]{#assess_question1_3_1_1_1_opt_a}
-   This is a correct way to move a turtle forward.
-   [forward() + 20]{#assess_question1_3_1_1_1_opt_b}
-   This does not use the turtle method necessary to move a turtle
    forward. Additionally, how would the program know what turtle should
    be moving?
-   [forward(20)]{#assess_question1_3_1_1_1_opt_c}
-   This does not use the turtle method necessary to move a turtle
    forward. Additionally, how would the program know what turtle should
    be moving?
-   [forward(20).Tex]{#assess_question1_3_1_1_1_opt_d}
-   This is not the correct structure to execute the task.
-   [Tex.forward(10 + 10)]{#assess_question1_3_1_1_1_opt_e}
-   You are allowed to write expressions inside of methods, so this is
    correctly written.
:::

::: {.runestone}
-   [turtle(Turtle)]{#assess_question1_3_1_1_2_opt_a}
-   When making a new instace of the turtle class, you need to use dot
    notation.
-   [turtle.Turtle()]{#assess_question1_3_1_1_2_opt_b}
-   Yes, this is the correct way.
-   [Turtle.turtle()]{#assess_question1_3_1_1_2_opt_c}
-   turtle represents the class and should be first.
-   [Turtle(turtle)]{#assess_question1_3_1_1_2_opt_d}
-   When making a new instace of the turtle class, you need to use dot
    notation.
:::

::: {.runestone}
-   [The turtle class.]{#assess_question1_3_1_1_3_opt_a}
-   Though each instance does use the turtle class, this is not the best
    answer.
-   [The same turtle that is used in each drawing your programs
    make.]{#assess_question1_3_1_1_3_opt_b}
-   Each instance that is made using the turtle class is unique.
    Remember how you can have multiple \'turtles\' in a single drawing?
    Each of those are different turtles but they are all instances of
    the turtle class.
-   [A unique \'turtle\' that you can use to
    draw.]{#assess_question1_3_1_1_3_opt_c}
-   Yes, an instance of the turtle class represents a unique turtle. The
    turtle class is like a stencil or mold that can be used to make as
    many turtles as you would like.
:::

::: {.runestone}
-   [Change the value of an attribute.]{#assess_question1_3_1_1_5_opt_a}
-   Methods can change the value that is associated with an attribute.
-   [Return values.]{#assess_question1_3_1_1_5_opt_b}
-   Methods can return values.
-   [Create new attributes of an instance and set their
    values.]{#assess_question1_3_1_1_5_opt_c}
-   Attributes do not need to be pre-declared; any code can add a new
    attribute to an instance just by assigning a value to it.
-   [Delete object instances.]{#assess_question1_3_1_1_5_opt_d}
-   You do not explicitly delete object instances; when there are no
    variables or other references to them, so that they can\'t be
    accessed, they are automatically deleted.
-   [None of the above.]{#assess_question1_3_1_1_5_opt_e}
-   Methods can do at least one of the above. Take another look.
:::

::: {.runestone}
-   [student.title()]{#assess_question1_3_1_1_6_opt_a}
-   This accesses the attribute but then tries to invoke it as a method,
    which will fail if title is not a method.
-   [title.student()]{#assess_question1_3_1_1_6_opt_b}
-   student is the object, so it goes before the period; the attribute
    goes after.
-   [title.student]{#assess_question1_3_1_1_6_opt_c}
-   student is the object, so it goes before the period; the attribute
    goes after.
-   [student(title)]{#assess_question1_3_1_1_6_opt_d}
-   This would be the syntax for a function named student being called
    on a variable named title.
-   [student.title]{#assess_question1_3_1_1_6_opt_e}
-   Yes, this is the correct syntax to use.
:::

::: {.runestone}
::: {#assess_question1_3_1_1_7 component="fillintheblank" question_label="5.11.6" style="visibility: hidden;"}
What is the name of jane's attribute (not method) that is referred to in
the following code?

::: {.highlight-python .notranslate}
::: {.highlight}
    import turtle

    jane = turtle.Turtle()
    jane.forward(20)
    print(jane.x)
:::
:::

The attribute is
:::
:::

::: {.runestone}
::: {#assess_question1_3_1_1_8 component="fillintheblank" question_label="5.11.7" style="visibility: hidden;"}
What are the names of the instances in the following code? Please put
one instance per blank space and enter them in the order that the
computer would read them.

::: {.highlight-python .notranslate}
::: {.highlight}
    import turtle
    wn = turtle.Screen()

    jazz = turtle.Turtle()
    jazz.forward(50)
    jazz.right(90)
    pop = turtle.Turtle()
    pop.left(180)
    pop.forward(76)
:::
:::
:::
:::
:::

::: {#chapter-assessment-drawing-with-turtle .section}
[5.12. ]{.section-number}Chapter Assessment - Drawing with Turtle[¶](#chapter-assessment-drawing-with-turtle "Permalink to this heading"){.headerlink}
======================================================================================================================================================

::: {.runestone .explainer .ac_section}
::: {#assess_ps_01_09a component="activecode" question_label="5.12.1"}
::: {#assess_ps_01_09a_question .ac_question}
Write code to draw a regular pentagon (a five-sided figure with all
sides the same length).
:::
:::
:::

::: {.runestone .explainer .ac_section}
::: {#assess_ps_01_09 component="activecode" question_label="5.12.2"}
::: {#assess_ps_01_09_question .ac_question}
Write a program that uses the turtle module to draw something. It
doesn't have to be complicated, but draw something different than we
have done in the past. (Hint: if you are drawing something complicated,
it could get tedious to watch it draw over and over. Try setting
`.speed(10)`{.docutils .literal .notranslate} for the turtle to draw
fast, or `.speed(0)`{.docutils .literal .notranslate} for it to draw
super fast with no animation.)
:::
:::
:::
:::

::: {style="width: 100%"}
::: {ea-publisher="runestoneacademy" ea-type="image" style="display: flex; justify-content: center"}
:::
:::

::: {#scprogresscontainer}
You have attempted []{#scprogresstotal} of []{#scprogressposs}
activities on this page

::: {#subchapterprogress aria-label="Page progress"}
:::
:::

-   [[](Exercises.html)]{#relations-prev}
-   [[](../Sequences/toctree.html)]{#relations-next}
:::

::: {.container}
[]{#numuserspan}[]{.loggedinuser} \| [Back to top](#)

© Copyright 2017 bradleymiller. Created using
[Runestone](http://runestoneinteractive.org/) 7.2.10.
:::
